package App::Greple::under::bake;
use strict;
use warnings;

use App::Greple::under ':all';

1;

__DATA__

option default \
    -Munder \
    --under-custom-colormap \
    --under-line \
    --re '\A' --all
